const axios = require('axios');
const md5 = require('js-md5');
const jsSHA = require('jssha');

const KEENETIC_IP = '192.168.1.1';
const LOGIN = 'admin';
const PASSWORD = '1';

const AUTH_URL = `http://${KEENETIC_IP}/auth`;
const RCI_URL_PREFIX = `http://${KEENETIC_IP}/rci`;

const getSha256Hash = (text) => {
  const shaObj = new jsSHA('SHA-256', 'TEXT');
  shaObj.update(text);
  return shaObj.getHash('HEX');
};

const getMd5HashArg = (login, realm, password) => `${login}:${realm}:${password}`;

const getCryptedPass = (login, password, token, realm) => {
  const md5Arg = getMd5HashArg(login, realm, password);
  const md5Hash = md5(md5Arg);

  return getSha256Hash(token + md5Hash);
}

const authPromise = new Promise((resolve, reject) => {
  axios.get(AUTH_URL)
    .then((res) => {
      console.log('NO PASSWORD');
      resolve();
    })
    .catch((err) => {
      const headers = err.response.headers;
      const token = headers['x-ndm-challenge'];
      const realm = headers['x-ndm-realm'];

      // DEBUG OUTPUT
      console.log(`TOKEN=<${token}>`);
      console.log(`REALM=<${realm}>`);
      console.log(headers);

      const cookies = headers['set-cookie'][0].split(';');

      // DEBUG OUTPUT
      console.log(`COOKIES=<${cookies}`);

      axios({
          method: 'post',
          url: AUTH_URL,
          headers: {
              Cookie: cookies[0]
          },
          data: {
            login: LOGIN,
            password: getCryptedPass(LOGIN, PASSWORD, token, realm)
          }
        })
        .then((res) => {
          console.log('AUTHORIZED!');
          resolve(cookies[0]);
        })
        .catch((err) => {
          console.log('ERROR', err);
          reject();
        });
    });
});

authPromise.then((cookie) => {
  let headers = {};

  if (cookie) {
    headers.Cookie = cookie;
  }

  axios({
    method: 'get',
    url: `${RCI_URL_PREFIX}/show/ip/hotspot`,
    headers: headers
  })
  .then(requestObj => {
    console.log(requestObj.data);
  });
})
